@@ -30,6 +30,8 @@
 #include <QUrl>
 
 #include <KAboutData>
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <KLocalizedString>
 #include <KDBusService>
 
@@ -55,7 +57,6 @@ int main( int argc, char **argv )
     aboutData.addCredit( QStringLiteral("Lukáš Tinkl"), i18n("Port to KF5/Plasma 5"), QStringLiteral("lukas@kde.org") );
 
     KAboutData::setApplicationData(aboutData);
-    KDBusService service(KDBusService::Unique);
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
@@ -68,6 +69,8 @@ int main( int argc, char **argv )
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
+    const bool multiple = KSharedConfig::openConfig()->group("KDE").readEntry("MultipleInstances", QVariant(false)).toBool();
+    KDBusService service(multiple ? KDBusService::Multiple : KDBusService::Unique);
     QObject::connect(&service, &KDBusService::activateRequested, &app, &Dragon::PlayerApplication::slotActivateRequested);
     QObject::connect(&service, &KDBusService::openRequested, &app, &Dragon::PlayerApplication::slotOpenRequested);
 
